<input id="{{ widget.id }}" type="text" name="{{ widget.input_name }}" value="{{ value|escape }}"
       class="init-block {%- if widget.classname %} {{ widget.classname }}{% endif %}"
       {%- if widget.size %} size="{{ widget.size }}"{% endif %}
       {%- if readonly %} readonly="readonly"{% endif %}
       data-block-name="{% if widget.js_block %}{{ widget.js_block }}{% else %}calendar{% endif %}"/>
