.filtr .block { float: left; margin-right: 10px; font-weight: bold; margin-bottom: 10px; }
.filtr .block DIV { margin-top: 0.2em; }
.filtr .block DIV DIV { padding-right: 0.2em; width: 1.8em; text-align: right; display: block; float: left; vertical-align: middle; }
.filtr INPUT { vertical-align: middle; }
.filtr .go { clear: both; float: right; padding: 0px 10px 0px 0px; }
.filtr .range { margin-top: -2px;  }
.filtr SPAN { padding: 0em 0.4em 0em 0.6em; }
.filtr .color { background-color: #fbfdf9; padding: 2px 2px; }
.filtr .nocolor { padding: 2px 2px; }
.filtr:after{
    content: '';
    clear: right;
    }

.stream{
    padding: 0;
    margin: 0;
    border-collapse:collapse;
    vertical-align: top;
    background-color:#F0F1F2;
    position: relative;
  }
  .stream table {
      border-collapse: collapse;
  }

.stream .line { background-color: #dedede; }
.stream th, .stream thead td {
    background-color: #F0F1F2;
    color: #000000;
    text-align: left;
    }
.stream th.sortable{
  padding-left: 22px;
  cursor: pointer;
  }
.stream th.sortable:before{
  content: "";
  background-image: url(../images/sort-icons.png);
  background-position: 4px 4px;
  background-repeat: no-repeat;
  padding-left: 22px;
  margin-left: -22px;
  }
  .stream th.sortable-asc:before{
    background-position: 4px -27px;
    }
  .stream th.sortable-desc:before{
    background-position: 4px -58px;
    }
  .stream th.sortable:hover{
    background-color: #F7F8F9;
    }

.stream-items.with-sidefilter {
  margin-right: 30px;
  }

.sidefilter{
  position: absolute;
  right: 0;
  top: 0;
  min-height: 100%;
  box-sizing: border-box;
  width: 30px;
  overflow: hidden;
  background-color:#F0F1F2;
  padding: 15px 0 0 0;
  -webkit-transition: width .2s ease-in;
  -moz-transition: width .2s ease-in;
  transition: width .2s ease-in;
  }
  .sidefilter.is-open{
    width:335px;
    }
  .sidefilter>form{
    width:320px;
    padding: 0 15px;
    }

  .sidefilter fieldset {
      border: none;
      padding-top: 15px;
      margin: 5px 0;
      -moz-border-radius: 5px;
      -webkit-border-radius: 5px;
      }

  .sidefilter legend {
      padding: 2px 8px;
      border: none;
      position: absolute;
      left: 0px;
      top: 0px;
      font-size: 16px;
      -webkit-transform: rotate(90deg) translate(70px, 25px);
      -moz-transform: rotate(90deg) translate(70px, 25px);
      transform: rotate(90deg) translate(70px, 25px);

      -webkit-transition: .2s ease-in;
      -moz-transition: .2s ease-in;
      transition: .2s ease-in;

      cursor: pointer;
    }
    .sidefilter.is-open legend {
      -webkit-transform: translate(30px, 10px);
      -moz-transform: translate(30px, 10px);
      transform: translate(30px, 10px);
      }
    .sidefilter-close{
      display: none;
      }

    .sidefilter-close{
        position: absolute;
        left: 0;
        top: 0;
        width: 30px;
        height: 100%;
        display: block;
        cursor: pointer;
        }
        .sidefilter-close:before{
          content: "<";
          font-size: 25;
          font-weight: bold;
          display: block;
          color: #555;
          width: 30px;
          margin-top: 6px;
          text-align: center;
          }
        .is-open .sidefilter-close:before{
          content: ">";
        }
        .sidefilter:hover .sidefilter-close{
          background-color: #ddd;
        }

      .sidefilter.is-open:hover .sidefilter-close{
        background-color: transparent;
        }
        .sidefilter.is-open .sidefilter-close:hover{
          background-color: #ddd;
        }
        .sidefilter-close:hover:before,
        .sidefilter-close:hover legend{
            color: #000;
          }

/*  .sidefilter-tags{
    padding: 2px 8px;
    border: none;
    position: absolute;
    left: 15px;
    top: 120px;
    font-size: 14px;
    -webkit-transform: translateX(-50%) rotate(90deg) translateX(50%);
    -moz-transform: translateX(-50%) rotate(90deg) translateX(50%);
    transform: translateX(-50%) rotate(90deg) translateX(50%);
    white-space: nowrap;
    cursor: pointer;
    }
    .sidefilter-tags span{
        background-color: #1abc9c;
        padding: 2px 4px;
        color: #fff;
        border-radius: 3px;
        max-width: 150px;
        text-overflow: ellipsis;
        display: inline-block;
        overflow: hidden;
        margin-right: 5px;
        }
  .sidefilter.is-open .sidefilter-tags{
    display: none;
    }*/

  .sidefilter .form-row {
      border-bottom:1px solid #ccc;
  }

  .sidefilter .form-row.last {
      border-bottom:none;
  }

  .sidefilter .form-row.hidden {
      display: none;
  }

  .sidefilter input, .sidefilter select {
      width: 75%;
  }

  .sidefilter .form-row input[type=checkbox] {
    width:15px;
  }

  .sidefilter__submit {
      margin: 10px 0;
      float:right;
  }

  .sidefilter__clear {
      margin: 10px 0;
  }

  .sidefilter th {
      vertical-align:top;
  }
  .sidefilter th label{
    display:block;
    margin:10px 0px 5px 0px ;
  }

  .sidefilter select{
    width:200px;
    border: 1px solid #ccc;
  }

.filter-form>fieldset>.form-row{
    padding: 5px 0 5px 20px;
    }
    .filter-form>fieldset>.form-row.full-width{
      padding-left: 0;
      }
    .filter-form label{
      font-size: 13px;
      padding-right: 10px;
      color: #333;
      }
    .filter-form>fieldset>.form-row>.form-label{
      font-weight: bold;
      font-size: 13px;
      padding-bottom: 3px;
      margin-left: -20px;
      }



.itemlist {
  padding: 71px 20px 0 20px;
}


.items {
  width:100%;
  }
  .items td, .items th{
    padding: 10px;
    margin: 0px;
    font-size:100%;
    }
    .items th.no-title{
      padding: 0;
      }


.w-popup-stream-select-items .odd td,
.items .odd td {
    background: #E2E4E6;
}
.w-popup-stream-select-items .even td,
.items .even td {
    background: #F0F1F2;
}

.id-field button{
  display: inline-block;
  margin-left: 5px;
  /* Arrow Right designed by P.J. Onori from The Noun Project */
  background: url(../images/go.svg) center center no-repeat;
  width: 20px;
  height: 20px;
  background-size: 20px;
  border: none;
  vertical-align: middle;
  cursor: pointer;
  }

.pages { white-space: nowrap; padding: 5px 0; height: 22px; background: #fff;}
.pages A { cursor: pointer; cursor: hand; text-decoration: none; }
.pages DIV { padding: 0.2em 0.6em; font: bold 1em Arial, sans-serif; color: #4a5761; background-color: #fbfbfb; border: 1px solid #ebebeb; margin-right: 10px; float: left; }
.pages .active { background-color: #c1c1c1; color: #ffffff; border: 1px solid #c1c1c1; }

.livesearch-wrap{
    padding: 2px 35px 2px 50px;
    position: relative;
    }

.livesearch{
    display: block;
    padding: 3px 5px;
    border: 1px solid #ccc;
    background: white;
    width: 100%;
    box-sizing: border-box;
    }
    .livesearch i{
        position: absolute;
        left: 5px;
        top: 50%;
        margin-top: -0.5em;
        font-style: normal;
        }
    .livesearch input{
        padding: 0;
        border: none;
        outline: none;
        max-width: 100%;
        box-sizing: border-box;
        }
    .livesearch span{
        background-color: #1abc9c;
        padding: 2px 4px;
        color: #fff;
        border-radius: 3px;
        max-width: 200px;
        text-overflow: ellipsis;
        display: inline-block;
        overflow: hidden;
        margin-right: 5px;
        vertical-align: middle;
        white-space: nowrap;
        }
    .livesearch.is-loading:after {
        content: '';
        position: absolute;
        top: 14px;
        right: 45px;
        width: 5px;
        height: 5px;
        border-radius: 3px;
        background-color: #1abc9c;
        animation: button-blink-opacity 1.4s infinite;
        }


.item img {
  border: none;
}

.items .odd td {
    background: hsl(0,0%,91%);
}
.items .even td {
    background: hsl(0,0%,93%);
}

/* Стили для родительских tr */
tr.odd.published td {
    background-color: hsl(120,80%,91%);
    }
tr.even.published td {
    background-color: hsl(120,80%,93%);
    }

tr.odd.unpublished td {
    background-color: hsl(20,80%,91%);
    }
tr.even.unpublished td {
    background-color: hsl(20,80%,93%);
    }

tr.odd.deleted td{
    color: #fff;
    background-color: hsl(0,80%,15%);
    }
tr.even.deleted td {
    background-color: hsl(0,80%,18%);
    }
tr.deleted td ,
tr.deleted td a{
    color: #fff;
    }

/* Стили для td-исключений */
tr.odd td.published {
    background-color: hsl(120,80%,91%);
    }
tr.even td.published {
    background-color: hsl(120,80%,93%);
    }

tr.odd td.unpublished {
    background-color: hsl(20,80%,91%);
    }
tr.even td.unpublished {
    background-color: hsl(20,80%,93%);
    }

/* Replacement of width="0%" in ListField */
.width-0 {
    width: 0;
}
