{{ field.get_field('mode').widget.render()|safe }}
{{ field.get_field('temp_name').widget.render()|safe }}
{{ field.get_field('original_name').widget.render()|safe }}

{% set value = field.clean_value %}

{% if value %}
    <a target="_blank" href="{{ value.url }}">
        {% if value.mode == 'existing' %}
            Прикреплённый файл
        {% else %}
            Временный загруженный файл
        {% endif %}
    </a><br/>
    {% if value and not required %}
        {{ field.get_field('delete').widget.render()|safe }}
        <label for="{{ field.get_field('delete').id }}">удалить</label>
        <br/>
    {% endif %}
{% endif %}

{{ field.get_field('file').widget.render()|safe }}
