{% extends "layout.html" %}

{% from "macros/filter_form.html" import sidefilter, paginate %}
{% set pager = paginate(paginator) %}

{% macro stream_content() %}
    {% if not changed %}
      <p>Очередь публикации пуста.</p>
    {% endif %}

    {{ pager }}
    <table class="items">
      <thead>
        <th>ID</th>
        <th>Тип</th>
        <th>Изменён</th>
        <th>Объект</th>
      </thead>
        <tbody>
        {% for stream, subenv, item in changed %}
          {% set item_url = stream.url_for(subenv, 'item', item=item.id) %}
          <tr class="item {{ loop.cycle('odd', 'even') }}
                     {%- if item.public is defined -%}
                       {%- if item.public %} published{% else %} unpublished{% endif -%}
                       {%- endif %}">
            <td class="field_id">
                <a href="{{ item_url }}">{{- item.id -}}</a>
            </td>
            <td class="field_id">
                <a href="{{ item_url }}">{{- stream.title -}}</a>
            </td>
            <td class="field_updated_dt">
                <a href="{{ item_url }}">{{- item.updated_dt.strftime("%d.%m.%Y %H:%M") -}}</a>
            </td>
            <td>
                <a href="{{ item_url }}">
                    {{- item.title if item.title is defined else item -}}
                <a>
            </td>
          </tr>
        {% endfor %}
        </tbody>
    </table>
    {{ pager }}
{% endmacro %}


{% block content %}
    {% if no_layout %}
        {{ stream_content() }}
    {% else %}
        <div class="content itemlist">
            <div class="header">
                <h1 class="stream_title nowrap">Очередь публикации</h1>
            </div>
            <div>
                <div class="stream">
                    <div class="line"></div>

                    <div class="stream-items with-sidefilter">
                        <p>Показываются все опубликованные объекты,
                           у которых имеются неопубликованные изменения
                           (давние правки&nbsp;&ndash; сверху).
                        </p>
                        {{ stream_content() }}
                    </div>
                </div>
            <div>
        </div>
    {% endif %}
{% endblock %}
