{% macro autosave_status(autosave_allowed, draft) %}
  {%- set autosave_status='no-changes' if autosave_allowed else '' -%}
  {%- if autosave_allowed and draft %}{% set autosave_status='draft' %}{% endif -%}
  <div class="autosave-status" data-status="{{ autosave_status }}">
    <div class="autosave-status__off" title="Некоторые поля, в частности, файловые, не поддерживают функцию автосохранения. Изменения в этих полях необходимо сохранять вручную">автосохранение отключено</div>
    <div class="autosave-status__no-changes">нет изменений</div>
    <div class="autosave-status__changed">изменено</div>
    <div class="autosave-status__saving">сохранение</div>
    <div class="autosave-status__lock">блокировка утеряна</div>
    <div class="autosave-status__draft" title="Сохранение документа в базу невозможно из-за ошибок заполнения">сохранён черновик</div>
    <div class="autosave-status__error">ошибки при сохранении</div>
    <div class="autosave-status__saved">сохранено</div>
  </div>
  {%- if draft -%}
  <div class="autosave-authors">авторы черновика:
    {% for author in draft.admins %}
      {{- author.name }}{% if not loop.last %}, {% endif %}
    {%- endfor -%}
  </div>
  {%- endif -%}
{% endmacro %}
