<tr>
  {% if not menu.has_children %}
    <td colspan="{{ menu.max_childs() }}">
      <a href="{{ menu.url }}">{{ menu.title }}</a>
    </td>
  {% else %}
    {% for submenu in menu.items %}
      <td>
        <a href="{{ submenu.url }}">{{ submenu.title }}</a>
      </td>
    {% endfor %}
  {% endif %}
</tr>
