<a data-wysihtml5-command="createLink" class="btn" data-help-message="{{ env.get_help('createLink', 'Wysiwyg')}}" >Вставить ссылку</a>
<div class="wysihtml5-dialog-place">
  <div class="wysihtml5-dialog" style="display: none;"
    id="{{ widget.id }}-create-link">
    <label>
      Ссылка:
      <input data-wysihtml5-dialog-field="href" value="http://" class="text">
    </label>
    <div class="nowrap">
      <a data-wysihtml5-dialog-action="save">Применить</a>
      <a data-wysihtml5-command="unlink">Удалить ссылку</a>
    </div>
    <!--a data-wysihtml5-dialog-action="cancel">Закрыть</a-->
  </div>
</div>
