<div class="id-field init-block" data-block-name="id-field" data-url="{{ env.stream.url_for(env, 'item', item='ID') }}">
  {% include "widgets/textinput.html" %}
  <button type="button" title="Перейти"></button>
</div>
