{% extends "layout.html" %}

{% block content %}
<table style="margin: auto; font-size: 16pt;" cellspacing="2em">
  <tbody>
    {% for row in dashboard.items %}
      {{ row.render() }}
    {% endfor %}
  </tbody>
</table>
{% endblock %}
